/**
 * 通用uni-app网络请求
 * 基于 Promise 对象实现更简单的 request 使用方式，支持请求和响应拦截
 */
export default {
  config: {
    baseUrl: "https://stock.szjixun.cn",
    header: {
      "Content-Type": "application/json;charset=UTF-8",
      // 'Content-Type':'application/x-www-form-urlencoded'
    },
    data: {},
    method: "GET",
    dataType: "json" /* 如设为json，会对返回的数据做一次 JSON.parse */,
    responseType: "text",
    success() {},
    fail() {},
    complete() {},
  },
  interceptor: {
    request: null,
    response: null,
  },
  request(options) {
    if (!options) {
      options = {};
    }
    options.baseUrl = options.baseUrl || this.config.baseUrl;
    options.dataType = options.dataType || this.config.dataType;
    options.url = options.baseUrl + options.url;
    options.data = options.data || {};
    options.method = options.method || this.config.method;
    //TODO 加密数据
    options.header = options.header || this.config.header;
    //TODO 数据签名
    let _token = {
      Authorization: uni.getStorageSync("token") || "undefined",
    };
    options.header = Object.assign({}, options.header, _token);

    return new Promise((resolve, reject) => {
      let _config = null;

      options.complete = (response) => {
        let statusCode = response.statusCode;
        response.config = _config;
        if (this.interceptor.response) {
          let newResponse = this.interceptor.response(response);
          if (newResponse) {
            response = newResponse;
          }
        }
        console.log(response);
        if (response.data.status === 401) {
          uni.$u.toast('登录过期，请重新登录');
          uni.removeStorageSync("token");
          uni.removeStorageSync("userInfo");
          uni.redirectTo({
            url: "/pages/login/login",
          });
        }
        // 统一的响应日志记录
        _reslog(response);
        if (statusCode === 200) {
          //成功
          resolve(response.data);
        } else {
          reject(response);
        }
      };

      _config = Object.assign({}, this.config, options);
      _config.requestId = new Date().getTime();

      if (this.interceptor.request) {
        this.interceptor.request(_config);
      }

      uni.request(_config);
    });
  },
  get(url, data, options) {
    if (!options) {
      options = {};
    }
    options.url = url;
    options.data = data;
    options.method = "GET";
    return this.request(options);
  },
  post(url, data, options, header) {
    if (!options) {
      options = {};
    }
    options.url = url;
    options.data = data;
    options.header = header;
    options.method = "POST";
    return this.request(options);
  },
  put(url, data, options) {
    if (!options) {
      options = {};
    }
    options.url = url;
    options.data = data;
    options.method = "PUT";
    return this.request(options);
  },
  delete(url, data, options) {
    if (!options) {
      options = {};
    }
    options.url = url;
    options.data = data;
    options.method = "DELETE";
    return this.request(options);
  },
};

/**
 * 响应接口日志记录
 */
function _reslog(res) {
  let _statusCode = res.data.status;
  //TODO 除了接口服务错误外，其他日志调接口异步写入日志数据库
  switch (_statusCode) {
    case 200:
      break;
    case 401:
      break;
    case 404:
      break;
    default:
      break;
  }
}
